### Documentation
https://kicad-draw.readthedocs.io/en/latest/

### Install
```
pip install kicad-draw
```

### Examples
[examples/kicad_helix_coil.ipynb
](https://github.com/t-sasatani/KiCad-coil-maker/blob/master/examples/kicad_helix_coil.ipynb)
<a href="https://colab.research.google.com/github/t-sasatani/KiCad-coil-maker/blob/master/examples/kicad_helix_coil.ipynb" target="_parent"><img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/></a>
